@@ -8,6 +8,7 @@
 #include "GVApi.h"
 #include "NotifyGVContactsTable.h"
 #include "NotifyGVInbox.h"
+#include "ConsoleThread.h"
 
 class MainWindow : public QObject
 {
@@ -15,7 +16,6 @@ class MainWindow : public QObject
 
 public:
     MainWindow(QObject *parent = 0);
-    void log (const QString &strText, int level = 10);
 
 private slots:
     void doWork ();
@@ -26,13 +26,13 @@ private slots:
     void inboxChanged ();
     void dailyTimeout();
 
+    void getOut();
+
 private:
-    void initLogging ();
     void doLogin ();
     void doLogout ();
     void startTimer ();
 
-    QString baseDir();
     bool checkParams ();
     bool cipher(const QByteArray &byIn, QByteArray &byOut, bool bEncrypt);
 
@@ -40,9 +40,6 @@ private:
     //! THE API
     GVApi           gvApi;
 
-    //! Logfile
-    QFile           fLogfile;
-
     // Settings parsed from the ini file
     QString strUser;
     QString strPass;
@@ -68,6 +65,9 @@ private:
 
     //! Number of times we checked
     quint64         checkCounter;
+
+    //! Thread to read the Console and quit
+    ConsoleThread  *consoleThread;
 };
 
 #endif //_MAINWINDOW_H_
