@@ -480,10 +480,20 @@ MainWindow::initQML ()
                   &oContacts, SLOT(refreshContacts()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigRefreshAllContacts()),
+                  &oContacts, SLOT(refreshAllContacts()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     rv = connect (gObj, SIGNAL(sigRefreshInbox()),
                   &oInbox,   SLOT(refresh()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL(sigRefreshAllInbox()),
+                  &oInbox,  SLOT(refreshFullInbox()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     rv = connect (gObj, SIGNAL(sigHaptic()),
                   this, SLOT(onBtnClickFroHapticFeedback()));
     Q_ASSERT(rv);
@@ -722,6 +732,7 @@ MainWindow::refreshRegisteredNumbers ()
             Q_WARN("Get registered numbers failed at the start!!!");
             break;
         }
+        gvApiProgressString = "Getting user phones";
     } while (0); // End cleanup block (not a loop)
 
     if (!rv) {
@@ -756,6 +767,7 @@ MainWindow::gotAllRegisteredPhones (AsyncTaskToken *token)
         setStatus ("GV callbacks retrieved.");
     } while (0); // End cleanup block (not a loop)
 
+    gvApiProgressString.clear ();
     token->deleteLater ();
 }//MainWindow::gotAllRegisteredPhones
 
@@ -1243,7 +1255,13 @@ MainWindow::getQMLObject(const char *pageName)
 void
 MainWindow::onSigGvApiProgress(double percent)
 {
-    QString msg = QString("Progress : %1%").arg (percent);
+    QString msg;
+
+    if (gvApiProgressString.isEmpty ()) {
+        msg = QString("Progress : %1%").arg(percent);
+    } else {
+        msg = QString("%1 : %2%").arg(gvApiProgressString).arg(percent);
+    }
     setStatus (msg);
 }//MainWindow::onSigGvApiProgress
 
